@@ -1,4 +1,4 @@
-#' @importFrom graphics image.default image par plot title box text axis plot.new plot.window rasterImage layout lcm
+#' @importFrom graphics image.default image par plot title box text axis plot.new plot.window rasterImage layout lcm contour
 #' @importFrom grDevices dev.capabilities dev.size grey rgb
 #' @importFrom utils head tail setTxtProgressBar txtProgressBar
 #' @importFrom stats na.omit runif aggregate setNames predict
@@ -12,7 +12,13 @@
 #' @import units
 NULL
 
+# re-export:
+#' @importFrom lwgeom st_transform_proj
+#' @export
+lwgeom::st_transform_proj
+
 setOldClass("stars")
+setOldClass("stars_proxy")
 
 .onLoad = function(libname, pkgname) {
 	register_all_s3_methods() # dynamically registers non-imported pkgs (tidyverse) # nocov
