@@ -1,4 +1,4 @@
-# examples with the sf::nc feature dataset
+# examples with the sf::nc polygon dataset NOT ABOUT NETCDF's, see e.g. stars.R netcdf.R
 suppressPackageStartupMessages(library(sf))
 nc = st_read(system.file("gpkg/nc.gpkg", package="sf"))
 m = st_set_geometry(nc, NULL)
@@ -29,8 +29,5 @@ split(foo, 3)
 st_crs(foo)
 plot(foo)
 
-# read_ncdf:
-f <- system.file("nc/reduced.nc", package = "stars")
-read_ncdf(f)
-read_ncdf(f, var = c("anom"))
-read_ncdf(f, ncsub = cbind(start = c(1, 1, 1, 1), count = c(10, 12, 1, 1)))
+# subset vector cube:
+foo[nc[1]]
